import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import services from '@/services';
import { convertUnits, formatNumber } from '@/utils/ui';
import { useRequest } from 'ahooks';
import { Progress, Statistic, StatisticProps } from 'antd';
import dayjs from 'dayjs';
import { useMemo, useState } from 'react';
import CountUp from 'react-countup';
import DateSelect from './DateSelect';
import styles from './index.less';
import LineCharts from './LineCharts';
const formatter: StatisticProps['formatter'] = (value: any) => {
  return (
    <CountUp
      end={formatNumber(value)?.num as number}
      separator=""
      decimals={formatNumber(value)?.unit == '万件' ? 2 : 0}
    />
  );
};

const commonStatistic = (
  value: number | string,
  fontSize: number | string = 30,
) => {
  return (
    <Statistic
      valueStyle={{ fontSize: fontSize, lineHeight: 1 }}
      value={value}
      formatter={() => (
        <CountUp
          end={value as number}
          separator=""
          preserveValue
          decimals={Number.isInteger(value) ? 0 : 2}
        />
      )}
    />
  );
};

const OperatingSituation = () => {
  const [searchParams, setSearchParams] = useState<any>({ type: 2 });
  const { dispatch } = useGlobalModalServices();

  const { data } = useRequest(
    () => services.CityProblemApi.getContentStatisticsV3(searchParams),
    {
      refreshDeps: [searchParams],
    },
  );

  const platformList = useMemo(() => {
    //市运行平台
    const scypt = data?.data?.items?.find(
      (item: any) => item.code === 'scypt',
    )?.value;
    //12345
    const complaint = data?.data?.items?.find(
      (item: any) => item.code === '12345',
    )?.value;
    //数字城管
    const szcg = data?.data?.items?.find(
      (item: any) => item.code === 'szcg',
    )?.value;
    //突出问题
    const tcwtts = data?.data?.items?.find(
      (item: any) => item.code === 'tcwtts',
    )?.value;
    //行走成都
    const walkCd = data?.data?.items?.find(
      (item: any) => item.code === '10',
    )?.value;
    //委内
    const wnywxt = data?.data?.items?.find(
      (item: any) => item.code === 'wnywxt',
    )?.value;

    return [
      {
        key: '1',
        name: '市城运平台',
        value: scypt,
        unit: formatNumber(scypt)?.unit,
        lineData: data?.data?.timeItems['scypt']?.map((item: any) => ({
          ...item,
          name: item.time,
        })),
        onClick: () => {
          dispatch?.push('UrbanOperation' as any, {
            title: '市城运平台推送',
            props: {
              sourceSystemCode: data?.data?.items?.find(
                (item: any) => item.code === 'scypt',
              )?.code,
              datetType: searchParams?.type,
              lineData: data?.data?.timeItems['scypt']?.map((item: any) => ({
                ...item,
                name: item.time,
              })),
              time: dayjs(searchParams?.time).format('YYYY-MM'),
            },
          });
        },
      },
      {
        key: '2',
        name: '12345市民投诉',
        unit: formatNumber(complaint)?.unit,
        value: complaint,
        lineData: data?.data?.timeItems['12345']?.map((item: any) => ({
          ...item,
          name: item.time,
        })),
        onClick: () => {
          dispatch?.push('UrbanOperation' as any, {
            title: '12345市民投诉',

            props: {
              sourceSystemCode: data?.data?.items?.find(
                (item: any) => item.code === '12345',
              )?.code,
              datetType: searchParams?.type,
              lineData: data?.data?.timeItems['12345']?.map((item: any) => ({
                ...item,
                name: item.time,
              })),
              time: dayjs(searchParams?.time).format('YYYY-MM'),
            },
          });
        },
      },
      {
        key: '3',
        name: '数字城管',
        value: szcg,
        unit: formatNumber(szcg)?.unit,
        lineData: data?.data?.timeItems['szcg']?.map((item: any) => ({
          ...item,
          name: item.time,
        })),
        onClick: () => {
          //CgftEvent
          dispatch?.push('UrbanOperation' as any, {
            title: '数字城管',

            props: {
              sourceSystemCode: data?.data?.items?.find(
                (item: any) => item.code === 'szcg',
              )?.code,
              datetType: searchParams?.type,
              lineData: data?.data?.timeItems['szcg']?.map((item: any) => ({
                ...item,
                name: item.time,
              })),
              time: dayjs(searchParams?.time).format('YYYY-MM'),
            },
          });
        },
      },
      {
        key: '22',
        name: '突出问题推送',
        value: tcwtts,
        unit: formatNumber(tcwtts)?.unit,
        lineData: data?.data?.timeItems['tcwtts']?.map((item: any) => ({
          ...item,
          name: item.time,
        })),

        onClick: () => {
          //,CgftEvent
          dispatch?.push('UrbanOperation' as any, {
            title: '突出问题推送',
            props: {
              singleType: '1',
              sourceSystemCode: data?.data?.items?.find(
                (item: any) => item.code === 'tcwtts',
              )?.code,
              datetType: searchParams?.type,
              lineData: data?.data?.timeItems['tcwtts']?.map((item: any) => ({
                ...item,
                name: item.time,
              })),
              time: dayjs(searchParams?.time).format('YYYY-MM'),
            },
          });
        },
      },
      {
        key: '5',
        name: '行走成都',

        unit: formatNumber(walkCd)?.unit,
        value: walkCd,

        lineData: data?.data?.timeItems['10']?.map((item: any) => ({
          ...item,
          name: item.time,
        })),
        onClick: () => {
          dispatch?.push('UrbanOperation' as any, {
            title: '行走成都',
            props: {
              sourceSystemCode: data?.data?.items?.find(
                (item: any) => item.code === '10',
              )?.code,
              datetType: searchParams?.type,
              lineData: data?.data?.timeItems['10']?.map((item: any) => ({
                ...item,
                name: item.time,
              })),
              time: dayjs(searchParams?.time).format('YYYY-MM'),
            },
          });
        },
      },
      {
        key: '6',
        name: '委内业务系统',
        value: wnywxt,
        unit: formatNumber(wnywxt)?.unit,
        lineData: data?.data?.timeItems['wnywxt']?.map((item: any) => ({
          ...item,
          name: item.time,
        })),
        onClick: () => {
          dispatch.push('UrbanOperation', {
            title: '委内业务',
            props: {
              sourceSystemCode: data?.data?.items?.find(
                (item: any) => item.code === 'wnywxt',
              )?.code,
              datetType: searchParams?.type,
              lineData: data?.data?.timeItems['wnywxt']?.map((item: any) => ({
                ...item,
                name: item.time,
              })),
              time: dayjs(searchParams?.time).format('YYYY-MM'),
              showSourceSelect: true,
              sourceType: 'wnywxt',
            },
          });
        },
      },
    ];
  }, [dispatch, data, searchParams]);

  return (
    <div className={styles.container}>
      <div className={styles.titleWarp}>
        <div className={styles.title}>运行态势</div>
        <div className={styles.select}>
          <DateSelect
            onSelectedDate={(e) => {
              console.log(e);
              const currentTime = dayjs().format('HH:mm:ss');
              let time = `${e.time} ${currentTime}`;
              if (e.type === '1') {
                time = dayjs(e.time).format('YYYY-01-01') + ' ' + currentTime;
              } else if (e.type === '2') {
                time = dayjs(e.time).format('YYYY-MM-01') + ' ' + currentTime;
              }
              setSearchParams({
                time: time,
                type: e.type,
              });
            }}
          />
        </div>
      </div>
      <div className={styles.content}>
        <div className={styles.platform}>
          {platformList?.map((item) => {
            return (
              <div
                className={styles.platItem}
                key={item?.key}
                onClick={() => {
                  item?.onClick?.();
                }}
              >
                <div className={styles.title}>{item?.name}</div>
                <LineCharts
                  data={item?.lineData}
                  style={{ width: 126, height: 30 }}
                />

                <div className={styles.countWarp}>
                  {commonStatistic(convertUnits(item.value)?.num, 36)}
                  <span className={styles.unit}>
                    {convertUnits(item.value)?.unit}
                  </span>
                </div>
              </div>
            );
          })}
        </div>
        <img
          src={require('@/assets/images/tljt.png')}
          alt=""
          style={{ marginTop: 10 }}
        />
        <div className={styles.rigth}>
          <div className={styles.topWarp}>
            <div className={styles.title}>城市管理综合问题总数</div>
            <div
              className={styles.countWarp}
              style={{ cursor: 'pointer' }}
              onClick={() => {
                // dispatch.push('GeneralSituation', {
                //   title: '事件总体情况',
                // });
                dispatch.push('UrbanOperation', {
                  title: '总体情况',
                  props: {
                    // sourceSystemCode: data?.data?.items?.find(
                    //   (item: any) => item.code === 'wnywxt',
                    // )?.code,
                    datetType: searchParams?.type,
                    lineData: data?.data?.timeItems[
                      '城市管理综合问题总数'
                    ]?.map((item: any) => ({
                      ...item,
                      name: item.time,
                    })),
                    time: dayjs(searchParams?.time).format('YYYY-MM'),
                    showSourceSelect: true,
                    sourceType: 'all',
                  },
                });
              }}
            >
              {commonStatistic(convertUnits(data?.data?.total?.value)?.num, 38)}
              <span className={styles.unit}>
                {convertUnits(data?.data?.total?.value)?.unit}
              </span>
            </div>
          </div>
          <div className={styles.roat} style={{ height: 40 }}></div>

          <LineCharts
            data={
              data?.data?.timeItems['城市管理综合问题总数']?.map(
                (item: any) => ({
                  ...item,
                  name: item.time,
                }),
              ) || []
            }
            style={{ width: '100%', height: 64 }}
          />
          <div className={styles.eventWarp}>
            <div className={styles.eventItem}>
              <img
                src={require('@/assets/images/evtIc1.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  {commonStatistic(
                    convertUnits(data?.data?.accept?.value)?.num,
                  )}
                  <span className={styles.unit}>
                    {convertUnits(data?.data?.accept?.value)?.unit}
                  </span>
                </div>
                <div className={styles.label}>立案</div>
              </div>
            </div>
            <div
              className={styles.eventItem}
              style={{ cursor: 'pointer' }}
              onClick={() => {
                dispatch.push('ToDisposed', {
                  title: '待处置事件',
                });
              }}
            >
              <img
                src={require('@/assets/images/evtIc4.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  {commonStatistic(
                    convertUnits(data?.data?.disposing?.value)?.num,
                  )}
                  <span className={styles.unit}>
                    {convertUnits(data?.data?.disposing?.value)?.unit}
                  </span>
                </div>
                <div className={styles.label}>处置中</div>
              </div>
            </div>
            <div className={styles.eventItem}>
              <img
                src={require('@/assets/images/evtIc2.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  {commonStatistic(convertUnits(data?.data?.close?.value)?.num)}
                  <span className={styles.unit}>
                    {convertUnits(data?.data?.close?.value)?.unit}
                  </span>
                </div>
                <div className={styles.label}>已结案</div>
              </div>
            </div>
            <div className={styles.eventItem}>
              <img
                src={require('@/assets/images/evtIc2.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  <span></span>
                  <Statistic
                    valueStyle={{ fontSize: 30, lineHeight: 1 }}
                    value={data?.data?.closeRate?.value}
                  />
                  <span className={styles.unit}>%</span>
                </div>
                <div className={styles.label}>结案率</div>
              </div>
            </div>
          </div>

          <div className={styles.issueWarp}>
            <div className={styles.topWarp}>
              <div className={styles.title}>疑难问题</div>
              <div
                className={styles.countWarp}
                onClick={() => {
                  dispatch.push('DifficultEvents', {
                    title: '疑难问题',
                  });
                }}
              >
                {commonStatistic(
                  convertUnits(data?.data?.totalKnotty?.value)?.num,
                )}
                <span className={styles.unit}>
                  {convertUnits(data?.data?.totalKnotty?.value)?.unit}
                </span>
              </div>
            </div>

            <div className={styles.progressWarp}>
              <Progress
                percent={
                  ((data?.data?.otherKnotty?.value +
                    data?.data?.cityKnotty?.value) /
                    data?.data?.totalKnotty?.value) *
                  100
                }
                size={{ height: 20 }}
                success={{
                  percent:
                    (data?.data?.cityKnotty?.value /
                      data?.data?.totalKnotty?.value) *
                    100,
                }}
                showInfo={false}
                strokeColor="rgb(255, 95, 95)"
              />
            </div>
            <div className={styles.botWarp}>
              <div className={styles.item}>
                <div
                  className={styles.dot}
                  style={{ background: 'rgb(255, 198, 20)' }}
                ></div>
                <span className={styles.name}>城市管理类</span>
                {commonStatistic(
                  convertUnits(data?.data?.cityKnotty?.value)?.num,
                  24,
                )}
                <span className={styles.unit}>
                  {convertUnits(data?.data?.cityKnotty?.value)?.unit}
                </span>
              </div>
              <div className={styles.item}>
                <div
                  className={styles.dot}
                  style={{ background: 'rgb(255, 95, 95)' }}
                ></div>
                <span className={styles.name}>其它</span>
                {commonStatistic(
                  convertUnits(data?.data?.otherKnotty?.value)?.num,
                  24,
                )}
                <span className={styles.unit}>
                  {convertUnits(data?.data?.otherKnotty?.value)?.unit}
                </span>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default OperatingSituation;
