import React, { useEffect, useState } from 'react';
import { Flex } from 'antd';
import DescriptionItem from '@/components/DescriptionItem';
import styles from './index.less';
import industry4_1 from '@/assets/images/industryNew/industry4-1.png';
import industry4_2 from '@/assets/images/industryNew/industry4-2.png';
import industry4_3 from '@/assets/images/industryNew/industry4-3.png';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import { useModel } from '@umijs/max';
import services from '@/services';

const Advertisement: React.FC = () => {
  const { initialState } = useModel('@@initialState');
  const { areaId } = initialState;
  const { dispatch } = useGlobalModalServices();
  const [eventCount, setEventCount] = useState(0);

  const [eventChartData, setEventChartData] = useState([]);
  const commonValueStyle = {
    background: 'linear-gradient(180deg, #9CF8F7 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '30px',
    fontWeight: 700,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    fontSize: '16px',
    fontWeight: 400,
  };

  const commonUnitStyle = {
    color: '#BCCEE9',
    fontSize: '16px',
  };

  const commonStyle = {
    // marginBottom: '-10px'
    marginTop: '-10px',
    padding: '10px 0 0 10px'
  }

  const getData = () => {
    const params = {
      industry: '01',
      dateType: 'today',
      objectId: areaId,
    };
    services.Physicalsign.getNormalEventCountApi(params).then((res: any) => {
      console.log(res);
      if (res.code === 200) {
        setEventCount(res.data?.problemCount);
      }
    });
  };

  const getEchartsData = () => {
    const params = {
      industry: '01',
      dateType: 'month',
      objectId: areaId,
    };
    services.Physicalsign.getNormalEventTrendApi(params).then((res: any) => {
      console.log(res);
      if (res.code === 200) {
        setEventChartData(res.data);
      }
    });
  };

  useEffect(() => {
    getData();
    getEchartsData();
  }, []);
  
  return (
    <div className={styles.container}>
      <DescriptionItem
        value={Number(eventCount)}
        name="本月发现问题"
        unit="件"
        valueStyle={commonValueStyle}
        labelStyle={commonLabelStyle}
        unitStyle={commonUnitStyle}
        decimals={0}
        style={{width: '205px'}}
        direction={'horizontal'}
        onClick={() => {
          dispatch.push('SanitationDisp', {
            title: '市容广告问题处置情况',
            props:{
              industry: '01',
            }
          });
        }}
      />

      <Flex gap={10}>
        <div className={styles.dataBox}>
          <img src={industry4_1} alt="" className={styles.bgImage} />
          <DescriptionItem
            value={56.01}
            name="共享单车投放"
            unit="万辆"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={2}
            style={commonStyle}
          />
        </div>
        <div className={styles.dataBox}>
          <img src={industry4_2} alt="" className={styles.bgImage} />
          <DescriptionItem
            value={100}
            name="门前五包签约率"
            unit="%"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={0}
            style={commonStyle}
          />
        </div>
        <div className={styles.dataBox}>
          <img src={industry4_3} alt="" className={styles.bgImage} />
          <DescriptionItem
            value={36.60}
            name="批准设置广告招牌"
            unit="万个"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={2}
            style={commonStyle}
          />
        </div>
      </Flex>
    </div>
  );
};

export default Advertisement; 