import React from 'react';
import { Flex } from 'antd';
import DescriptionItem from '@/components/DescriptionItem';
import styles from './index.less';
import industry6_1 from '@/assets/images/industryNew/industry6-1.png';
import industry6_2 from '@/assets/images/industryNew/industry6-2.png';
import industry6_3 from '@/assets/images/industryNew/industry6-3.png';
import services from '@/services';
import { useRequest } from 'ahooks';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';

const LawEnforcement: React.FC = () => {
  const { dispatch } = useGlobalModalServices();
  const commonValueStyle = {
    background: 'linear-gradient(180deg, #9CF8F7 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '30px',
    fontWeight: 700,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    fontSize: '16px',
    fontWeight: 400,
  };

  const commonUnitStyle = {
    color: '#BCCEE9',
    fontSize: '16px',
  };

  const { data } = useRequest(() =>
    services.DataBase.getSjdzInfoData({
      typeCode: 'zzcc-xzcf-xzcfsl',
    }),
  );

  return (
    <div className={styles.container}>
      <Flex gap={20}>
        <div className={styles.dataBox}>
          <img src={industry6_1} alt="" className={styles.bgImage} />
          <DescriptionItem
            value={data?.data?.data?.records?.[0]?.xzcf ?? 0}
            name="本月行政处罚"
            unit="件"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={0}
            onClick={() => {
              dispatch.push('AdministPunish');
            }}
          />
        </div>
        <div className={styles.dataBox}>
          <img src={industry6_2} alt="" className={styles.bgImage} />
          <DescriptionItem
            value={data?.data?.data?.records?.[0]?.sqxt ?? 0}
            name="本月市区协同"
            unit="件"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={0}
            onClick={() => {
              dispatch.push('AreaSynergy');
              // dispatch.push('EquipResource')
            }}
          />
        </div>
        <div className={styles.dataBox}>
          <img src={industry6_3} alt="" className={styles.bgImage} />
          <DescriptionItem
            value={data?.data?.data?.records?.[0]?.rcxc ?? 0}
            name="今日日常巡查"
            unit="件"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={0}
            onClick={() => {
              dispatch.push('DyaPatrol',);
           }}
          />
        </div>
      </Flex>
    </div>
  );
};

export default LawEnforcement; 