import React from 'react';
import { Flex } from 'antd';
import DescriptionItem from '@/components/DescriptionItem';
import styles from './index.less';
import industry2_1 from '@/assets/images/industryNew/industry2-1.png';
import industry2_2 from '@/assets/images/industryNew/industry2-2.png';
import industryTitle1 from '@/assets/images/industryNew/industryTitle1.png';
import industryTitle2 from '@/assets/images/industryNew/industryTitle2.png';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';

const WasteDisposal: React.FC = () => {
  const { dispatch } = useGlobalModalServices();

  const commonValueStyle = {
    background: 'linear-gradient(180deg, #9CF8F7 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '26px',
    fontWeight: 700,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    fontSize: '16px',
    fontWeight: 400,
    marginTop: '-8px',// 添加这行来缩短间距
  };

  const commonUnitStyle = {
    color: '#BCCEE9',
    fontSize: '16px',
  };

  const commonStyle = {
    marginTop: '-14px',
    padding: '0px 0 0 0px'
  }

  const handleClick = () => {
    dispatch.push('ConstructionWaste', {
      style: {
        top: 30,
      },
    });
  };
  
  const handleLivingGarbageClick = () => {
    dispatch.push('LivingGarbage', {
      style: {
        top: 30,
      },
    });
  };
  
  return (
    <div className={styles.container}>
      {/* 生活垃圾区域 */}
      <div className={styles.section}>
        <img src={industryTitle1} alt="生活垃圾" className={styles.titleImage} 
              onClick={handleLivingGarbageClick}/>
        <div className={styles.dataBox}>
          <img src={industry2_1} alt="" className={styles.bgImage} />
          <Flex gap={35}>
            <DescriptionItem
              value={14.05}
              name="本月处置总量"
              unit="万吨"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={2}
              style={commonStyle}
            />
            <DescriptionItem
              value={56.82}
              name="本月焚烧量"
              unit="万吨"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={2}
              style={commonStyle}
            />
            <DescriptionItem
              value={56.82}
              name="本月填埋量"
              unit="万吨"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={2}
              style={commonStyle}
              onClick={handleLivingGarbageClick}
            />
          </Flex>
        </div>
      </div>

      {/* 建筑垃圾区域 */}
      <div className={styles.section}>
        <img src={industryTitle2} alt="建筑垃圾" className={styles.titleImage} 
              onClick={handleClick}/>
        <div className={styles.dataBox}>
          <img src={industry2_2} alt="" className={styles.bgImage} />
          <Flex gap={35}>
            <DescriptionItem
              value={14.05}
              name="本月申报排放量"
              unit="万方"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={2}
              style={commonStyle}
            />
            <DescriptionItem
              value={2387}
              name="本月发现问题"
              unit="件"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={0}
              style={commonStyle}
              onClick={handleClick}
            />
          </Flex>
        </div>
      </div>
    </div>
  );
};

export default WasteDisposal; 